# PySentry - pip-audit Benchmark Report

**Generated:** 2026-02-06 10:36:26
**Duration:** 1m 59.69s
**Total Tests:** 20

## Executive Summary

**Overall Success Rate:** 100.0% (20/20 successful runs)

### Small_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.780s) - 12.64x faster than slowest
- **Memory Efficient:** pysentry-osv (18.11 MB) - 5.45x less memory than highest

### Small_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.438s) - 18.86x faster than slowest
- **Memory Efficient:** pysentry-osv (11.06 MB) - 6.52x less memory than highest

### Large_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (1.542s) - 13.27x faster than slowest
- **Memory Efficient:** pysentry-osv (37.28 MB) - 3.00x less memory than highest

### Large_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (1.114s) - 14.50x faster than slowest
- **Memory Efficient:** pysentry-osv (12.13 MB) - 6.48x less memory than highest

## Test Environment

- **Platform:** Linux-6.11.0-1018-azure-x86_64-with-glibc2.39
- **Python Version:** 3.11.14
- **CPU Cores:** 4
- **Total Memory:** 15.62 GB
- **Available Memory:** 14.70 GB

## Performance Comparison

### Small_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.780s | 1.00x |
| 🥈 pysentry-osv | 1.008s | 1.29x |
|  pysentry-all-sources | 1.670s | 2.14x |
|  pysentry-pypa | 1.949s | 2.50x |
|  pip-audit-default | 9.861s | 12.64x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 18.11 MB | 1.00x |
| 🥈 pysentry-pypi | 19.40 MB | 1.07x |
|  pip-audit-default | 45.71 MB | 2.52x |
|  pysentry-pypa | 68.22 MB | 3.77x |
|  pysentry-all-sources | 98.73 MB | 5.45x |

### Small_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.438s | 1.00x |
| 🥈 pysentry-osv | 0.620s | 1.42x |
|  pysentry-pypa | 1.418s | 3.24x |
|  pysentry-all-sources | 1.489s | 3.40x |
|  pip-audit-default | 8.255s | 18.86x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 11.06 MB | 1.00x |
| 🥈 pysentry-pypi | 11.82 MB | 1.07x |
|  pip-audit-default | 45.13 MB | 4.08x |
|  pysentry-pypa | 61.72 MB | 5.58x |
|  pysentry-all-sources | 72.18 MB | 6.52x |

### Large_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 1.542s | 1.00x |
| 🥈 pysentry-osv | 1.669s | 1.08x |
|  pysentry-pypa | 2.196s | 1.42x |
|  pysentry-all-sources | 2.328s | 1.51x |
|  pip-audit-default | 20.468s | 13.27x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 37.28 MB | 1.00x |
| 🥈 pysentry-pypi | 39.66 MB | 1.06x |
|  pip-audit-default | 47.77 MB | 1.28x |
|  pysentry-pypa | 81.13 MB | 2.18x |
|  pysentry-all-sources | 111.89 MB | 3.00x |

### Large_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 1.114s | 1.00x |
| 🥈 pysentry-osv | 1.307s | 1.17x |
|  pysentry-pypa | 1.892s | 1.70x |
|  pysentry-all-sources | 1.915s | 1.72x |
|  pip-audit-default | 16.157s | 14.50x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 12.13 MB | 1.00x |
| 🥈 pysentry-pypi | 13.38 MB | 1.10x |
|  pysentry-pypa | 48.24 MB | 3.98x |
|  pip-audit-default | 48.51 MB | 4.00x |
|  pysentry-all-sources | 78.65 MB | 6.48x |

## Detailed Analysis

### Pysentry Performance

- **Execution Time:** Avg: 1.458s, Min: 0.438s, Max: 2.328s

- **Memory Usage:** Avg: 48.97 MB, Min: 11.06 MB, Max: 111.89 MB

- **Success Rate:** 100.0% (16/16)

### Pip-Audit Performance

- **Execution Time:** Avg: 13.685s, Min: 8.255s, Max: 20.468s

- **Memory Usage:** Avg: 46.78 MB, Min: 45.13 MB, Max: 48.51 MB

- **Success Rate:** 100.0% (4/4)